@@ -24,6 +24,9 @@ class ActionUpdater:
         self.quiet = quiet
         self.c = Console()
 
+        # If using for a GitHub action, a global flag that indicates changes
+        self.has_changes = False
+
         # If we don't have default settings, load
         if not hasattr(self, "settings"):
             self.settings = Settings(settings_file)
@@ -87,13 +90,14 @@ class ActionUpdater:
 
                 # The count reflects the last run
                 if updater.detect(action):
-                    self.c.print(f"[red]❌ {updater.title} Updater: {updater.count} updates[/red]")
+                    self.c.print(f"[red]✖️ {updater.title} Updater: {updater.count} updates[/red]")
+                    self.has_changes = True
                 else:
                     self.c.print(f"[green]✔ {updater.title}: No updates[/green]")
 
             # If we want to show details:
             if details:
-                action.diff()
+                action.diff(self.settings.code_theme or "vim")
             actions[path] = action
         return actions
 
@@ -104,7 +108,7 @@ class ActionUpdater:
         actions = self.detect(paths, details=details, updaters=updaters)
         for path, action in actions.items():
             if action.has_changes:
-                self.c.print("[purple]❇ Writing updated {path}[/purple]")
+                self.c.print(f"[purple]❇ Writing updated {path}[/purple]")
                 action.write(path)
 
     def __repr__(self):
